from __future__ import annotations

from typing import TYPE_CHECKING, Any

from .base import TelegramObject

if TYPE_CHECKING:
    from .message import Message


class ChecklistTasksDone(TelegramObject):
    """
    Describes a service message about checklist tasks marked as done or not done.

    Source: https://core.telegram.org/bots/api#checklisttasksdone
    """

    checklist_message: Message | None = None
    """*Optional*. Message containing the checklist whose tasks were marked as done or not done. Note that the :class:`aiogram.types.message.Message` object in this field will not contain the *reply_to_message* field even if it itself is a reply."""
    marked_as_done_task_ids: list[int] | None = None
    """*Optional*. Identifiers of the tasks that were marked as done"""
    marked_as_not_done_task_ids: list[int] | None = None
    """*Optional*. Identifiers of the tasks that were marked as not done"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            checklist_message: Message | None = None,
            marked_as_done_task_ids: list[int] | None = None,
            marked_as_not_done_task_ids: list[int] | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                checklist_message=checklist_message,
                marked_as_done_task_ids=marked_as_done_task_ids,
                marked_as_not_done_task_ids=marked_as_not_done_task_ids,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from .base import TelegramObject

if TYPE_CHECKING:
    from .gift import Gift


class Gifts(TelegramObject):
    """
    This object represent a list of gifts.

    Source: https://core.telegram.org/bots/api#gifts
    """

    gifts: list[Gift]
    """The list of gifts"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(__pydantic__self__, *, gifts: list[Gift], **__pydantic_kwargs: Any) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(gifts=gifts, **__pydantic_kwargs)



from collections.abc import Mapping
from typing import Any, overload

from aiogram.fsm.storage.base import BaseStorage, StateType, StorageKey


class FSMContext:
    def __init__(self, storage: BaseStorage, key: StorageKey) -> None:
        self.storage = storage
        self.key = key

    async def set_state(self, state: StateType = None) -> None:
        await self.storage.set_state(key=self.key, state=state)

    async def get_state(self) -> str | None:
        return await self.storage.get_state(key=self.key)

    async def set_data(self, data: Mapping[str, Any]) -> None:
        await self.storage.set_data(key=self.key, data=data)

    async def get_data(self) -> dict[str, Any]:
        return await self.storage.get_data(key=self.key)

    @overload
    async def get_value(self, key: str) -> Any | None: ...

    @overload
    async def get_value(self, key: str, default: Any) -> Any: ...

    async def get_value(self, key: str, default: Any | None = None) -> Any | None:
        return await self.storage.get_value(storage_key=self.key, dict_key=key, default=default)

    async def update_data(
        self,
        data: Mapping[str, Any] | None = None,
        **kwargs: Any,
    ) -> dict[str, Any]:
        if data:
            kwargs.update(data)
        return await self.storage.update_data(key=self.key, data=kwargs)

    async def clear(self) -> None:
        await self.set_state(state=None)
        await self.set_data({})



from asyncio import Lock
from collections import defaultdict
from collections.abc import AsyncGenerator, Hashable, Mapping
from contextlib import asynccontextmanager
from copy import copy
from dataclasses import dataclass, field
from typing import Any, overload

from aiogram.exceptions import DataNotDictLikeError
from aiogram.fsm.state import State
from aiogram.fsm.storage.base import (
    BaseEventIsolation,
    BaseStorage,
    StateType,
    StorageKey,
)


@dataclass
class MemoryStorageRecord:
    data: dict[str, Any] = field(default_factory=dict)
    state: str | None = None


class MemoryStorage(BaseStorage):
    """
    Default FSM storage; uses a regular :class:`dict` to store data and
    does not persist it across restarts.

    .. warning::

        This storage is not recommended for production use, as all data is lost
        when the bot restarts
    """

    def __init__(self) -> None:
        self.storage: defaultdict[StorageKey, MemoryStorageRecord] = defaultdict(
            MemoryStorageRecord,
        )

    async def close(self) -> None:
        pass

    async def set_state(self, key: StorageKey, state: StateType = None) -> None:
        self.storage[key].state = state.state if isinstance(state, State) else state

    async def get_state(self, key: StorageKey) -> str | None:
        return self.storage[key].state

    async def set_data(self, key: StorageKey, data: Mapping[str, Any]) -> None:
        if not isinstance(data, dict):
            msg = f"Data must be a dict or dict-like object, got {type(data).__name__}"
            raise DataNotDictLikeError(msg)
        self.storage[key].data = data.copy()

    async def get_data(self, key: StorageKey) -> dict[str, Any]:
        return self.storage[key].data.copy()

    @overload
    async def get_value(self, storage_key: StorageKey, dict_key: str) -> Any | None: ...

    @overload
    async def get_value(self, storage_key: StorageKey, dict_key: str, default: Any) -> Any: ...

    async def get_value(
        self,
        storage_key: StorageKey,
        dict_key: str,
        default: Any | None = None,
    ) -> Any | None:
        data = self.storage[storage_key].data
        return copy(data.get(dict_key, default))


class DisabledEventIsolation(BaseEventIsolation):
    @asynccontextmanager
    async def lock(self, key: StorageKey) -> AsyncGenerator[None, None]:
        yield

    async def close(self) -> None:
        pass


class SimpleEventIsolation(BaseEventIsolation):
    def __init__(self) -> None:
        # TODO: Unused locks cleaner is needed
        self._locks: defaultdict[Hashable, Lock] = defaultdict(Lock)

    @asynccontextmanager
    async def lock(self, key: StorageKey) -> AsyncGenerator[None, None]:
        lock = self._locks[key]
        async with lock:
            yield

    async def close(self) -> None:
        self._locks.clear()



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Literal

from aiogram.enums import OwnedGiftType

from .custom import DateTime
from .owned_gift import OwnedGift

if TYPE_CHECKING:
    from .unique_gift import UniqueGift
    from .user import User


class OwnedGiftUnique(OwnedGift):
    """
    Describes a unique gift received and owned by a user or a chat.

    Source: https://core.telegram.org/bots/api#ownedgiftunique
    """

    type: Literal[OwnedGiftType.UNIQUE] = OwnedGiftType.UNIQUE
    """Type of the gift, always 'unique'"""
    gift: UniqueGift
    """Information about the unique gift"""
    send_date: int
    """Date the gift was sent in Unix time"""
    owned_gift_id: str | None = None
    """*Optional*. Unique identifier of the received gift for the bot; for gifts received on behalf of business accounts only"""
    sender_user: User | None = None
    """*Optional*. Sender of the gift if it is a known user"""
    is_saved: bool | None = None
    """*Optional*. :code:`True`, if the gift is displayed on the account's profile page; for gifts received on behalf of business accounts only"""
    can_be_transferred: bool | None = None
    """*Optional*. :code:`True`, if the gift can be transferred to another owner; for gifts received on behalf of business accounts only"""
    transfer_star_count: int | None = None
    """*Optional*. Number of Telegram Stars that must be paid to transfer the gift; omitted if the bot cannot transfer the gift"""
    next_transfer_date: DateTime | None = None
    """*Optional*. Point in time (Unix timestamp) when the gift can be transferred. If it is in the past, then the gift can be transferred now"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: Literal[OwnedGiftType.UNIQUE] = OwnedGiftType.UNIQUE,
            gift: UniqueGift,
            send_date: int,
            owned_gift_id: str | None = None,
            sender_user: User | None = None,
            is_saved: bool | None = None,
            can_be_transferred: bool | None = None,
            transfer_star_count: int | None = None,
            next_transfer_date: DateTime | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                type=type,
                gift=gift,
                send_date=send_date,
                owned_gift_id=owned_gift_id,
                sender_user=sender_user,
                is_saved=is_saved,
                can_be_transferred=can_be_transferred,
                transfer_star_count=transfer_star_count,
                next_transfer_date=next_transfer_date,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from .base import TelegramObject

if TYPE_CHECKING:
    from .photo_size import PhotoSize


class LivePhoto(TelegramObject):
    """
    This object represents a live photo.

    Source: https://core.telegram.org/bots/api#livephoto
    """

    file_id: str
    """Identifier for the video file which can be used to download or reuse the file"""
    file_unique_id: str
    """Unique identifier for the video file which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file."""
    width: int
    """Video width as defined by the sender"""
    height: int
    """Video height as defined by the sender"""
    duration: int
    """Duration of the video in seconds as defined by the sender"""
    photo: list[PhotoSize] | None = None
    """*Optional*. Available sizes of the corresponding static photo"""
    mime_type: str | None = None
    """*Optional*. MIME type of the file as defined by the sender"""
    file_size: int | None = None
    """*Optional*. File size in bytes. It can be bigger than 2^31 and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this value."""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            file_id: str,
            file_unique_id: str,
            width: int,
            height: int,
            duration: int,
            photo: list[PhotoSize] | None = None,
            mime_type: str | None = None,
            file_size: int | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                file_id=file_id,
                file_unique_id=file_unique_id,
                width=width,
                height=height,
                duration=duration,
                photo=photo,
                mime_type=mime_type,
                file_size=file_size,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from .base import TelegramObject


class ForumTopicReopened(TelegramObject):
    """
    This object represents a service message about a forum topic reopened in the chat. Currently holds no information.

    Source: https://core.telegram.org/bots/api#forumtopicreopened
    """



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from .base import TelegramObject

if TYPE_CHECKING:
    from .photo_size import PhotoSize


class SharedUser(TelegramObject):
    """
    This object contains information about a user that was shared with the bot using a :class:`aiogram.types.keyboard_button_request_users.KeyboardButtonRequestUsers` button.

    Source: https://core.telegram.org/bots/api#shareduser
    """

    user_id: int
    """Identifier of the shared user. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so 64-bit integers or double-precision float types are safe for storing these identifiers. The bot may not have access to the user and could be unable to use this identifier, unless the user is already known to the bot by some other means."""
    first_name: str | None = None
    """*Optional*. First name of the user, if the name was requested by the bot"""
    last_name: str | None = None
    """*Optional*. Last name of the user, if the name was requested by the bot"""
    username: str | None = None
    """*Optional*. Username of the user, if the username was requested by the bot"""
    photo: list[PhotoSize] | None = None
    """*Optional*. Available sizes of the chat photo, if the photo was requested by the bot"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            user_id: int,
            first_name: str | None = None,
            last_name: str | None = None,
            username: str | None = None,
            photo: list[PhotoSize] | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                user_id=user_id,
                first_name=first_name,
                last_name=last_name,
                username=username,
                photo=photo,
                **__pydantic_kwargs,
            )



from typing import TYPE_CHECKING, Any

from ..types import ChatIdUnion
from .base import TelegramMethod


class DeleteMessageReaction(TelegramMethod[bool]):
    """
    Use this method to remove a reaction from a message in a group or a supergroup chat. The bot must have the 'can_delete_messages' administrator right in the chat. Returns :code:`True` on success.

    Source: https://core.telegram.org/bots/api#deletemessagereaction
    """

    __returning__ = bool
    __api_method__ = "deleteMessageReaction"

    chat_id: ChatIdUnion
    """Unique identifier for the target chat or username of the target supergroup (in the format :code:`@username`)"""
    message_id: int
    """Identifier of the target message"""
    user_id: int | None = None
    """Identifier of the user whose reaction will be removed, if the reaction was added by a user"""
    actor_chat_id: int | None = None
    """Identifier of the chat whose reaction will be removed, if the reaction was added by a chat"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            chat_id: ChatIdUnion,
            message_id: int,
            user_id: int | None = None,
            actor_chat_id: int | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                chat_id=chat_id,
                message_id=message_id,
                user_id=user_id,
                actor_chat_id=actor_chat_id,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from .base import TelegramObject

if TYPE_CHECKING:
    from .paid_media_union import PaidMediaUnion


class PaidMediaInfo(TelegramObject):
    """
    Describes the paid media added to a message.

    Source: https://core.telegram.org/bots/api#paidmediainfo
    """

    star_count: int
    """The number of Telegram Stars that must be paid to buy access to the media"""
    paid_media: list[PaidMediaUnion]
    """Information about the paid media"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            star_count: int,
            paid_media: list[PaidMediaUnion],
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(star_count=star_count, paid_media=paid_media, **__pydantic_kwargs)



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from .base import TelegramMethod


class ReadBusinessMessage(TelegramMethod[bool]):
    """
    Marks incoming message as read on behalf of a business account. Requires the *can_read_messages* business bot right. Returns :code:`True` on success.

    Source: https://core.telegram.org/bots/api#readbusinessmessage
    """

    __returning__ = bool
    __api_method__ = "readBusinessMessage"

    business_connection_id: str
    """Unique identifier of the business connection on behalf of which to read the message"""
    chat_id: int
    """Unique identifier of the chat in which the message was received. The chat must have been active in the last 24 hours."""
    message_id: int
    """Unique identifier of the message to mark as read"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            business_connection_id: str,
            chat_id: int,
            message_id: int,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                business_connection_id=business_connection_id,
                chat_id=chat_id,
                message_id=message_id,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from typing import TypeAlias

from .reaction_type_custom_emoji import ReactionTypeCustomEmoji
from .reaction_type_emoji import ReactionTypeEmoji
from .reaction_type_paid import ReactionTypePaid

ReactionTypeUnion: TypeAlias = ReactionTypeEmoji | ReactionTypeCustomEmoji | ReactionTypePaid



from abc import ABC

from aiogram.handlers.base import BaseHandler


class ErrorHandler(BaseHandler[Exception], ABC):
    """
    Base class for errors handlers
    """

    @property
    def exception_name(self) -> str:
        return self.event.__class__.__name__

    @property
    def exception_message(self) -> str:
        return str(self.event)



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from ..utils.text_decorations import add_surrogates, remove_surrogates
from .base import MutableTelegramObject

if TYPE_CHECKING:
    from .user import User


class MessageEntity(MutableTelegramObject):
    """
    This object represents one special entity in a text message. For example, hashtags, usernames, URLs, etc.

    Source: https://core.telegram.org/bots/api#messageentity
    """

    type: str
    """Type of the entity. Currently, can be 'mention' (:code:`@username`), 'hashtag' (:code:`#hashtag` or :code:`#hashtag@chatusername`), 'cashtag' (:code:`$USD` or :code:`$USD@chatusername`), 'bot_command' (:code:`/start@jobs_bot`), 'url' (:code:`https://telegram.org`), 'email' (:code:`do-not-reply@telegram.org`), 'phone_number' (:code:`+1-212-555-0123`), 'bold' (**bold text**), 'italic' (*italic text*), 'underline' (underlined text), 'strikethrough' (strikethrough text), 'spoiler' (spoiler message), 'blockquote' (block quotation), 'expandable_blockquote' (collapsed-by-default block quotation), 'code' (monowidth string), 'pre' (monowidth block), 'text_link' (for clickable text URLs), 'text_mention' (for users `without usernames <https://telegram.org/blog/edit#new-mentions>`_), 'custom_emoji' (for inline custom emoji stickers), or 'date_time' (for formatted date and time)"""
    offset: int
    """Offset in `UTF-16 code units <https://core.telegram.org/api/entities#entity-length>`_ to the start of the entity"""
    length: int
    """Length of the entity in `UTF-16 code units <https://core.telegram.org/api/entities#entity-length>`_"""
    url: str | None = None
    """*Optional*. For 'text_link' only, URL that will be opened after user taps on the text"""
    user: User | None = None
    """*Optional*. For 'text_mention' only, the mentioned user"""
    language: str | None = None
    """*Optional*. For 'pre' only, the programming language of the entity text"""
    custom_emoji_id: str | None = None
    """*Optional*. For 'custom_emoji' only, unique identifier of the custom emoji. Use :class:`aiogram.methods.get_custom_emoji_stickers.GetCustomEmojiStickers` to get full information about the sticker"""
    unix_time: int | None = None
    """*Optional*. For 'date_time' only, the Unix time associated with the entity"""
    date_time_format: str | None = None
    """*Optional*. For 'date_time' only, the string that defines the formatting of the date and time. See `date-time entity formatting <https://core.telegram.org/bots/api#date-time-entity-formatting>`_ for more details."""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: str,
            offset: int,
            length: int,
            url: str | None = None,
            user: User | None = None,
            language: str | None = None,
            custom_emoji_id: str | None = None,
            unix_time: int | None = None,
            date_time_format: str | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                type=type,
                offset=offset,
                length=length,
                url=url,
                user=user,
                language=language,
                custom_emoji_id=custom_emoji_id,
                unix_time=unix_time,
                date_time_format=date_time_format,
                **__pydantic_kwargs,
            )

    def extract_from(self, text: str) -> str:
        return remove_surrogates(
            add_surrogates(text)[self.offset * 2 : (self.offset + self.length) * 2]
        )



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from .base import TelegramObject


class PaidMessagePriceChanged(TelegramObject):
    """
    Describes a service message about a change in the price of paid messages within a chat.

    Source: https://core.telegram.org/bots/api#paidmessagepricechanged
    """

    paid_message_star_count: int
    """The new number of Telegram Stars that must be paid by non-administrator users of the supergroup chat for each sent message"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__, *, paid_message_star_count: int, **__pydantic_kwargs: Any
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(paid_message_star_count=paid_message_star_count, **__pydantic_kwargs)



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from ..client.default import Default
from .base import TelegramObject

if TYPE_CHECKING:
    from .input_poll_option_media import InputPollOptionMedia
    from .input_poll_option_media_union import InputPollOptionMediaUnion
    from .message_entity import MessageEntity


class InputPollOption(TelegramObject):
    """
    This object contains information about one answer option in a poll to be sent.

    Source: https://core.telegram.org/bots/api#inputpolloption
    """

    text: str
    """Option text, 1-100 characters"""
    text_parse_mode: str | Default | None = Default("parse_mode")
    """*Optional*. Mode for parsing entities in the text. See `formatting options <https://core.telegram.org/bots/api#formatting-options>`_ for more details. Currently, only custom emoji entities are allowed"""
    text_entities: list[MessageEntity] | None = None
    """*Optional*. A JSON-serialized list of special entities that appear in the poll option text. It can be specified instead of *text_parse_mode*"""
    media: InputPollOptionMediaUnion | None = None
    """*Optional*. Media added to the poll option"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            text: str,
            text_parse_mode: str | Default | None = Default("parse_mode"),
            text_entities: list[MessageEntity] | None = None,
            media: InputPollOptionMediaUnion | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                text=text,
                text_parse_mode=text_parse_mode,
                text_entities=text_entities,
                media=media,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Literal

from aiogram.enums import StoryAreaTypeType

from .story_area_type import StoryAreaType


class StoryAreaTypeWeather(StoryAreaType):
    """
    Describes a story area containing weather information. Currently, a story can have up to 3 weather areas.

    Source: https://core.telegram.org/bots/api#storyareatypeweather
    """

    type: Literal[StoryAreaTypeType.WEATHER] = StoryAreaTypeType.WEATHER
    """Type of the area, always 'weather'"""
    temperature: float
    """Temperature, in degree Celsius"""
    emoji: str
    """Emoji representing the weather"""
    background_color: int
    """A color of the area background in the ARGB format"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: Literal[StoryAreaTypeType.WEATHER] = StoryAreaTypeType.WEATHER,
            temperature: float,
            emoji: str,
            background_color: int,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                type=type,
                temperature=temperature,
                emoji=emoji,
                background_color=background_color,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from .base import TelegramObject

if TYPE_CHECKING:
    from .story_area_position import StoryAreaPosition
    from .story_area_type_union import StoryAreaTypeUnion


class StoryArea(TelegramObject):
    """
    Describes a clickable area on a story media.

    Source: https://core.telegram.org/bots/api#storyarea
    """

    position: StoryAreaPosition
    """Position of the area"""
    type: StoryAreaTypeUnion
    """Type of the area"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            position: StoryAreaPosition,
            type: StoryAreaTypeUnion,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(position=position, type=type, **__pydantic_kwargs)



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Literal

from ..enums import ChatMemberStatus
from .chat_member import ChatMember
from .custom import DateTime

if TYPE_CHECKING:
    from .user import User


class ChatMemberBanned(ChatMember):
    """
    Represents a `chat member <https://core.telegram.org/bots/api#chatmember>`_ that was banned in the chat and can't return to the chat or view chat messages.

    Source: https://core.telegram.org/bots/api#chatmemberbanned
    """

    status: Literal[ChatMemberStatus.KICKED] = ChatMemberStatus.KICKED
    """The member's status in the chat, always 'kicked'"""
    user: User
    """Information about the user"""
    until_date: DateTime
    """Date when restrictions will be lifted for this user; Unix time. If 0, then the user is banned forever"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            status: Literal[ChatMemberStatus.KICKED] = ChatMemberStatus.KICKED,
            user: User,
            until_date: DateTime,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(status=status, user=user, until_date=until_date, **__pydantic_kwargs)



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Literal

from .background_type import BackgroundType

if TYPE_CHECKING:
    from .background_fill_union import BackgroundFillUnion


class BackgroundTypeFill(BackgroundType):
    """
    The background is automatically filled based on the selected colors.

    Source: https://core.telegram.org/bots/api#backgroundtypefill
    """

    type: Literal["fill"] = "fill"
    """Type of the background, always 'fill'"""
    fill: BackgroundFillUnion
    """The background fill"""
    dark_theme_dimming: int
    """Dimming of the background in dark themes, as a percentage; 0-100"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: Literal["fill"] = "fill",
            fill: BackgroundFillUnion,
            dark_theme_dimming: int,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                type=type, fill=fill, dark_theme_dimming=dark_theme_dimming, **__pydantic_kwargs
            )



from typing import TypeAlias

from .input_profile_photo_animated import InputProfilePhotoAnimated
from .input_profile_photo_static import InputProfilePhotoStatic

InputProfilePhotoUnion: TypeAlias = InputProfilePhotoStatic | InputProfilePhotoAnimated
